@@ -1,4 +1,5 @@
 import io
+from PIL import Image
 from .KerasNeuralNetwork import KerasNeuralNetwork
 from .utils import Decoder_FEN, Tiler
 try:
@@ -9,13 +10,25 @@ except ImportError:
 from board_to_fen import saved_models
 
 
-def get_fen_from_image(image_path, end_of_row='/', black_view=False) -> str:
+def get_fen_from_image_path(image_path, end_of_row='/', black_view=False) -> str:
+    image = Image.open(image_path)
     decoder = Decoder_FEN()
     net = KerasNeuralNetwork()
     f = pkg_resources.open_text(saved_models, 'november_model')
     net.load_model(f.name)
     tiler = Tiler()
-    tiles = tiler.get_tiles(image_path=image_path)
+    tiles = tiler.get_tiles(image=image)
     predictions = net.predict(tiles=tiles)
     fen = decoder.fen_decode(squares=predictions, end_of_row=end_of_row, black_view=black_view)
     return fen
+
+def get_fen_from_image(image, end_of_row='/', black_view=False) -> str:
+    decoder = Decoder_FEN()
+    net = KerasNeuralNetwork()
+    f = pkg_resources.open_text(saved_models, 'november_model')
+    net.load_model(f.name)
+    tiler = Tiler()
+    tiles = tiler.get_tiles(image=image)
+    predictions = net.predict(tiles=tiles)
+    fen = decoder.fen_decode(squares=predictions, end_of_row=end_of_row, black_view=black_view)
+    return fen
\ No newline at end of file
